@@ -100,7 +100,7 @@ def test_pass_env_config_default(tox_project: ToxProjectCreator, stdout_is_atty:
     expected = (
         (["COMSPEC"] if is_win else [])
         + ["CURL_CA_BUNDLE", "LANG", "LANGUAGE", "LD_LIBRARY_PATH"]
-        + (["MSYSTEM", "PATHEXT"] if is_win else [])
+        + (["MSYSTEM", "NUMBER_OF_PROCESSORS", "PATHEXT"] if is_win else [])
         + ["PIP_*"]
         + (["PROCESSOR_ARCHITECTURE"] if is_win else [])
         + (["PROGRAMDATA"] if is_win else [])
@@ -160,7 +160,7 @@ def test_show_config_select_only(tox_project: ToxProjectCreator) -> None:
 def test_show_config_alias(tox_project: ToxProjectCreator) -> None:
     outcome = tox_project({"tox.ini": ""}).run("c", "-e", "py", "-k", "setenv")
     outcome.assert_success()
-    assert "set_env = " in outcome.out
+    assert "set_env =" in outcome.out
 
 
 def test_show_config_description_normalize(tox_project: ToxProjectCreator) -> None:
@@ -219,3 +219,10 @@ def test_show_config_timeout_custom(tox_project: ToxProjectCreator) -> None:
 def test_show_config_help(tox_project: ToxProjectCreator) -> None:
     outcome = tox_project({"tox.ini": ""}).run("c", "-h")
     outcome.assert_success()
+
+
+def test_show_config_core_host_python(tox_project: ToxProjectCreator) -> None:
+    project = tox_project({"tox.ini": ""})
+    outcome = project.run("c", "--core", "-e", "py", "-k", "host_python")
+    outcome.assert_success()
+    assert f"host_python = {sys.executable}" in outcome.out
